package JavaScript::MochiKit::Async;

use strict;
use base qw[
  JavaScript::MochiKit::Accessor
];
use vars qw [ @Dependencies ];

@Dependencies = qw [ Base ];


1;
